Exec { timeout => hiera('DEFAULT_EXEC_TIMEOUT') }

$neutron_db_host         = hiera('CONFIG_MARIADB_HOST')
$neutron_db_name         = hiera('CONFIG_NEUTRON_L2_DBNAME')
$neutron_db_user         = 'neutron'
$neutron_db_password     = hiera('CONFIG_NEUTRON_DB_PW')
$neutron_sql_connection  = "mysql://${neutron_db_user}:${neutron_db_password}@${neutron_db_host}/${neutron_db_name}"
$neutron_user_password   = hiera('CONFIG_NEUTRON_KS_PW')



class { 'neutron':
  rabbit_host           => hiera('CONFIG_AMQP_HOST'),
  rabbit_port           => hiera('CONFIG_AMQP_CLIENTS_PORT'),
  rabbit_user           => hiera('CONFIG_AMQP_AUTH_USER'),
  rabbit_password       => hiera('CONFIG_AMQP_AUTH_PASSWORD'),
  core_plugin           => hiera('CONFIG_NEUTRON_CORE_PLUGIN'),
  allow_overlapping_ips => true,
  service_plugins       => hiera_array('SERVICE_PLUGINS'),
  verbose               => true,
  debug                 => hiera('CONFIG_DEBUG_MODE'),
}

class { 'neutron::server':
  database_connection => $neutron_sql_connection,
  auth_password       => $neutron_user_password,
  auth_host           => hiera('CONFIG_CONTROLLER_HOST'),
  enabled             => true,
}

exec { 'neutron-db-manage upgrade':
  command   => 'neutron-db-manage --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugin.ini upgrade head',
  path      => '/usr/bin',
  user      => 'neutron',
  logoutput => 'on_failure',
  before    => Service['neutron-server'],
  require   => [Neutron_config['database/connection'], Neutron_config['DEFAULT/core_plugin']],
}

$neutron_notif_cfg_ctrl_host = hiera('CONFIG_CONTROLLER_HOST')

# Configure nova notifications system
class { 'neutron::server::notifications':
  nova_admin_username    => 'nova',
  nova_admin_password    => hiera('CONFIG_NOVA_KS_PW'),
  nova_admin_tenant_name => 'services',
  nova_url               => "http://${neutron_notif_cfg_ctrl_host}:8774/v2",
  nova_admin_auth_url    => "http://${neutron_notif_cfg_ctrl_host}:35357/v2.0",
  nova_region_name       => hiera('CONFIG_KEYSTONE_REGION'),
}

if hiera('CONFIG_NEUTRON_ML2_VXLAN_GROUP') == '' {
  $vxlan_group_value = undef
} else {
  $vxlan_group_value = hiera('CONFIG_NEUTRON_ML2_VXLAN_GROUP')
}

class { 'neutron::plugins::ml2':
  type_drivers          => hiera_array('CONFIG_NEUTRON_ML2_TYPE_DRIVERS'),
  tenant_network_types  => hiera_array('CONFIG_NEUTRON_ML2_TENANT_NETWORK_TYPES'),
  mechanism_drivers     => hiera_array('CONFIG_NEUTRON_ML2_MECHANISM_DRIVERS'),
  flat_networks         => hiera_array('CONFIG_NEUTRON_ML2_FLAT_NETWORKS'),
  network_vlan_ranges   => hiera_array('CONFIG_NEUTRON_ML2_VLAN_RANGES'),
  tunnel_id_ranges      => hiera_array('CONFIG_NEUTRON_ML2_TUNNEL_ID_RANGES'),
  vxlan_group           => $vxlan_group_value,
  vni_ranges            => hiera_array('CONFIG_NEUTRON_ML2_VNI_RANGES'),
  enable_security_group => true,
}

# For cases where "neutron-db-manage upgrade" command is called
# we need to fill config file first
if defined(Exec['neutron-db-manage upgrade']) {
  Neutron_plugin_ml2<||> ->
  File['/etc/neutron/plugin.ini'] ->
  Exec['neutron-db-manage upgrade']
}
create_resources(packstack::firewall, hiera('FIREWALL_NEUTRON_SERVER_RULES', {}))


create_resources(packstack::firewall, hiera('FIREWALL_NEUTRON_TUNNEL_RULES_10.35.186.254_10.35.186.254', {}))


class { 'neutron::agents::l3':
  interface_driver        => hiera('CONFIG_NEUTRON_L3_INTERFACE_DRIVER'),
  external_network_bridge => hiera('CONFIG_NEUTRON_L3_EXT_BRIDGE'),
  debug                   => hiera('CONFIG_DEBUG_MODE'),
}

sysctl::value { 'net.ipv4.ip_forward':
  value => '1',
}


$cfg_neutron_ovs_host = '10.35.186.254'
$ovs_agent_vxlan_cfg_neut_ovs_tun_if = hiera('CONFIG_NEUTRON_OVS_TUNNEL_IF',undef)

if $ovs_agent_vxlan_cfg_neut_ovs_tun_if != '' {
  $iface = regsubst($ovs_agent_vxlan_cfg_neut_ovs_tun_if, '[\.\-\:]', '_', 'G')
  $localip = inline_template("<%= scope.lookupvar('::ipaddress_${iface}') %>")
} else {
  $localip = $cfg_neutron_ovs_host
}

class { 'neutron::agents::ml2::ovs':
  bridge_mappings  => hiera_array('CONFIG_NEUTRON_OVS_BRIDGE_MAPPINGS'),
  enable_tunneling => hiera('CONFIG_NEUTRON_OVS_TUNNELING'),
  tunnel_types     => hiera_array('CONFIG_NEUTRON_OVS_TUNNEL_TYPES'),
  local_ip         => $localip,
  vxlan_udp_port   => hiera('CONFIG_NEUTRON_OVS_VXLAN_UDP_PORT',undef),
  l2_population    => hiera('CONFIG_NEUTRON_USE_L2POPULATION'),
}


$cfg_neutron_ovs_iface = hiera('CONFIG_NEUTRON_OVS_IFACE')

vs_port { $cfg_neutron_ovs_iface:
  ensure => present,
  bridge => hiera('CONFIG_NEUTRON_OVS_BRIDGE'),
}




class { 'packstack::neutron::bridge': }


class { 'neutron::agents::dhcp':
  interface_driver    => hiera('CONFIG_NEUTRON_DHCP_INTERFACE_DRIVER'),
  debug               => hiera('CONFIG_DEBUG_MODE'),
  dnsmasq_config_file => '/etc/neutron/dnsmasq-neutron.conf',
  require             => File['/etc/neutron/dnsmasq-neutron.conf'],
}

file { '/etc/neutron/dnsmasq-neutron.conf':
  content => 'dhcp-option-force=26,1400',
  owner   => 'root',
  group   => 'neutron',
  mode    => '0640',
}

create_resources(packstack::firewall, hiera('FIREWALL_NEUTRON_DHCPIN_RULES', {}))

create_resources(packstack::firewall, hiera('FIREWALL_NEUTRON_DHCPOUT_RULES', {}))


$neutron_metadata_cfg_ctrl_host = hiera('CONFIG_CONTROLLER_HOST')

class { 'neutron::agents::metadata':
  auth_password => hiera('CONFIG_NEUTRON_KS_PW'),
  auth_url      => "http://${neutron_metadata_cfg_ctrl_host}:35357/v2.0",
  auth_region   => hiera('CONFIG_KEYSTONE_REGION'),
  shared_secret => hiera('CONFIG_NEUTRON_METADATA_PW'),
  metadata_ip   => hiera('CONFIG_CONTROLLER_HOST'),
  debug         => hiera('CONFIG_DEBUG_MODE'),
}

